Winnipeg Tournament Winnipeg, Manitoba April 27th 2003 10 players John Pattie Deck Name: Blood Hoover Basically a cel/tha blood draining and burning deck. Anathema for pool gain. Crypt (12 cards, min=11, max=40, avg=6.5) ----------------------------------------- 3x Anastasz di Zagreb 8 AUS THA ani cel dom justicar Tremere:3 2x Lucas Halton 10 AUS CEL DOM THA qui prince Tremere:3 2x Menele 10 CEL POT PRE THA aus dom Brujah:3 2x Blythe Candeleria 3 THA aus Tremere:2 2x Masika St. John 3 THA Tremere:3 1x Heinrick Schlempt 2 tha Tremere antitribu:2 Library (90 cards) Master (12) 2x Blood Doll 2x Celerity 1x Elder Library 1x Minion Tap 1x Rumor Mill, Tabloid Newspaper, The 1x Sudden Reversal 3x Tomb of Rameses III 1x Tribute to the Master Action (9) 4x Bum's Rush -- Need some Harass in here for 2nd round fun 3x Nose of the Hound 2x Rutor's Hand Equipment (1) 1x IR Goggles -- will probably remove for wake or deflection Political Action (5) 1x Anarchist Uprising 3x Anathema 1x Archon Action Modifier (5) 5x Conditioning -- used only at lesser to avoid archons. Only 1 vamp had superior dom. Reaction (12) 2x Deflection 2x Eagle's Sight 2x Forced Awakening 1x My Enemy's Enemy 3x Second Tradition: Domain 2x Wake with Evening's Freshness Combat (46) 4x Apportation 1x Blood Rage 4x Blur 2x Drain Essence 4x Flash 3x Lightning Reflexes 4x Psyche! 2x Pursuit 1x Shotgun Ritual 2x Sideslip 10x Theft of Vitae 4x Vampiric Speed 5x Walk of Flame -- - might remove 1 or 2 for burst of sunlight